#!/usr/bin/python
# Copyright 2007 by Bdale Garbee <bdale@gag.com>.  GPLv2
#
# Program to emit PCB footprint for ALPS SKQU Series 4-direction switch
#

# dimensions in mm from abm8.pdf Abracon datasheet
BodySquare = 10			# body outline
Column = 10.3			# space between pin columns
Row = 6.5			# space between top and bottom pin rows
Offset = 0.45			# offset of middle row below center line
BigPin = 1.2			# hole diameter for big pins
SmallPin = 1.0			# hole diameter for small pins

import sys

# we're going to use the 1/100 of a mil fundamental unit form
def mm2mils100( mm ):
	return int( mm / 25.4 * 1000.0 * 100.0 + 0.5 )

print '# author: Bdale Garbee'
print '# email: bdale@gag.com'
print '# dist-license: GPL 2'
print '# use-license: unlimited'

print 'Element[0x0 "SKQU" "" "" 0 0 0 0 0 100 0x0]'
print "("
print '   Pin[',\
 	mm2mils100(-Column/2), \
	mm2mils100(-Row/2), \
 	mm2mils100(2), \
	mm2mils100(1), \
	mm2mils100(2.2), \
	mm2mils100(BigPin), \
	'"pin1" "1" 0x0101]'

print '   Pin[',\
 	mm2mils100(-Column/2), \
 	mm2mils100(Offset), \
 	mm2mils100(2), \
	mm2mils100(1), \
	mm2mils100(2.2), \
	mm2mils100(SmallPin), \
	'"pin2" "2" 0x0001]'

print '   Pin[',\
 	mm2mils100(-Column/2), \
	mm2mils100(Row/2), \
 	mm2mils100(2), \
	mm2mils100(1), \
	mm2mils100(2.2), \
	mm2mils100(BigPin), \
	'"pin3" "3" 0x0001]'

print '   Pin[',\
 	mm2mils100(Column/2), \
	mm2mils100(-Row/2), \
 	mm2mils100(2), \
	mm2mils100(1), \
	mm2mils100(2.2), \
	mm2mils100(BigPin), \
	'"pin6" "6" 0x0001]'

print '   Pin[',\
 	mm2mils100(Column/2), \
 	mm2mils100(Offset), \
 	mm2mils100(2), \
	mm2mils100(1), \
	mm2mils100(2.2), \
	mm2mils100(SmallPin), \
	'"pin5" "5" 0x0001]'

print '   Pin[',\
 	mm2mils100(Column/2), \
	mm2mils100(Row/2), \
 	mm2mils100(2), \
	mm2mils100(1), \
	mm2mils100(2.2), \
	mm2mils100(BigPin), \
	'"pin4" "4" 0x0001]'

print '   ElementLine[',\
 	-mm2mils100(BodySquare/2), \
 	-mm2mils100(BodySquare/2), \
 	mm2mils100(BodySquare/2), \
 	-mm2mils100(BodySquare/2), \
	500, \
	']'
print '   ElementLine[',\
 	-mm2mils100(BodySquare/2), \
	-mm2mils100(BodySquare/2), \
 	-mm2mils100(BodySquare/2), \
	mm2mils100(BodySquare/2), \
	500, \
	']'
print '   ElementLine[',\
 	-mm2mils100(BodySquare/2), \
	mm2mils100(BodySquare/2), \
 	mm2mils100(BodySquare/2), \
	mm2mils100(BodySquare/2), \
	500, \
	']'
print '   ElementLine[',\
 	mm2mils100(BodySquare/2), \
	mm2mils100(BodySquare/2), \
 	mm2mils100(BodySquare/2), \
	-mm2mils100(BodySquare/2), \
	500, \
	']'

print '   ElementArc[',\
 	0, \
	0, \
 	mm2mils100(6.5/2), \
	mm2mils100(6.5/2), \
	0, \
	360, \
	500, \
	']'

print ")"
